Class: Symbol

Inherits:
Object show all
Defined in:
lib/kirbybase.rb

Overview


Symbol

Instance Method Summary collapse

Instance Method Details

#+@ ⇒ Object


+@

This allows you to put a plus sign in front of a field name in order to specify ascending sort order.



3918
3919
3920
# File 'lib/kirbybase.rb', line 3918

def +@
    ("+"+self.to_s).to_sym
end

#-@ ⇒ Object


-@

This allows you to put a minus sign in front of a field name in order to specify descending sort order.



3908
3909
3910
# File 'lib/kirbybase.rb', line 3908

def -@
    ("-"+self.to_s).to_sym
end